@@ -1,3 +1,3 @@
-library(symbolicDA) 
+require(symbolicDA)
 data("cars",package="symbolicDA")
 save.SO(cars,file="cars_backup.xml")
